@@ -65,11 +65,11 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
     Example::
 
         // Usage
-        const roots = DependableTrait.get(construct).dependencyRoots;
+        const roots = Dependable.of(construct).dependencyRoots;
         
         // Definition
-        DependableTrait.implement(construct, {
-          get dependencyRoots() { return []; }
+        Dependable.implement(construct, {
+              dependencyRoots: [construct],
         });
     '''
 
@@ -148,7 +148,7 @@ class IDependable(typing_extensions.Protocol):
     '''Trait marker for classes that can be depended upon.
 
     The presence of this interface indicates that an object has
-    an ``IDependableTrait`` implementation.
+    an ``IDependable`` implementation.
 
     This interface can be used to take an (ordering) dependency on a set of
     constructs. An ordering dependency implies that the resources represented by
@@ -163,7 +163,7 @@ class _IDependableProxy:
     '''Trait marker for classes that can be depended upon.
 
     The presence of this interface indicates that an object has
-    an ``IDependableTrait`` implementation.
+    an ``IDependable`` implementation.
 
     This interface can be used to take an (ordering) dependency on a set of
     constructs. An ordering dependency implies that the resources represented by
@@ -180,19 +180,12 @@ typing.cast(typing.Any, IDependable).__jsii_proxy_class__ = lambda : _IDependabl
 
 @jsii.interface(jsii_type="constructs.IValidation")
 class IValidation(typing_extensions.Protocol):
-    '''Implement this interface in order for the construct to be able to validate itself.
-
-    Implement this interface in order for the construct to be able to validate itself.
-    '''
+    '''Implement this interface in order for the construct to be able to validate itself.'''
 
     @jsii.member(jsii_name="validate")
     def validate(self) -> typing.List[builtins.str]:
         '''Validate the current construct.
 
-        This method can be implemented by derived constructs in order to perform
-        validation logic. It is called on all constructs before synthesis.
-        Validate the current construct.
-
         This method can be implemented by derived constructs in order to perform
         validation logic. It is called on all constructs before synthesis.
 
@@ -202,10 +195,7 @@ class IValidation(typing_extensions.Protocol):
 
 
 class _IValidationProxy:
-    '''Implement this interface in order for the construct to be able to validate itself.
-
-    Implement this interface in order for the construct to be able to validate itself.
-    '''
+    '''Implement this interface in order for the construct to be able to validate itself.'''
 
     __jsii_type__: typing.ClassVar[str] = "constructs.IValidation"
 
@@ -213,10 +203,6 @@ class _IValidationProxy:
     def validate(self) -> typing.List[builtins.str]:
         '''Validate the current construct.
 
-        This method can be implemented by derived constructs in order to perform
-        validation logic. It is called on all constructs before synthesis.
-        Validate the current construct.
-
         This method can be implemented by derived constructs in order to perform
         validation logic. It is called on all constructs before synthesis.
 
